@@ -2,9 +2,13 @@
 package Net::WebSocket::EVx;
 use strict; use warnings;
 use EV ();
+use Alien::Wslay;
 use XSLoader ();
 our $VERSION;
-BEGIN { $VERSION = '0.12'; XSLoader::load() }
+BEGIN {
+    $VERSION = '0.13';
+    XSLoader::load(__PACKAGE__, $VERSION);
+}
 use constant { WS_FRAGMENTED_EOF => 0, WS_FRAGMENTED_ERROR => -1, WS_FRAGMENTED_DATA => 1 };
 use Exporter 'import';
 our @EXPORT = qw/WS_FRAGMENTED_EOF WS_FRAGMENTED_ERROR WS_FRAGMENTED_NODATA/;
